Package: swagger
Type: Package
Title: Dynamically Generates Documentation from a 'Swagger' Compliant
        API
Version: 5.32.1
Authors@R: c(
    person("Barret", "Schloerke", role = "aut", email = "barret@rstudio.com", comment = c(ORCID = "0000-0001-9986-114X")),
    person("Javier", "Luraschi", role = "aut", email = "javier@rstudio.com"),
    person("Bruno", "Tremblay", role = c("cre", "ctb"), email = "cran@neoxone.com"),
    person(family = "RStudio", role = "cph"),
    person(family = "SmartBear Software", role = c("aut", "cph"))
    )
Suggests: jsonlite, plumber, testthat
Description: A collection of 'HTML', 'JavaScript', and 'CSS' assets that
  dynamically generate beautiful documentation from a 'Swagger' compliant API:
  <https://swagger.io/specification/>.
License: Apache License 2.0 | file LICENSE
Encoding: UTF-8
URL: https://rstudio.github.io/swagger/,
        https://github.com/rstudio/swagger
BugReports: https://github.com/rstudio/swagger/issues
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-03-27 15:27:27 UTC; bruno
Author: Barret Schloerke [aut] (ORCID: <https://orcid.org/0000-0001-9986-114X>),
  Javier Luraschi [aut],
  Bruno Tremblay [cre, ctb],
  RStudio [cph],
  SmartBear Software [aut, cph]
Maintainer: Bruno Tremblay <cran@neoxone.com>
Repository: CRAN
Date/Publication: 2026-03-28 06:10:24 UTC
Built: R 4.6.0; ; 2026-04-26 11:16:08 UTC; unix
