# swagger-rs

[![Build Status](https://travis-ci.org/Metaswitch/swagger-rs.svg?branch=master)](https://travis-ci.org/Metaswitch/swagger-rs)
[![crates.io](https://img.shields.io/crates/v/swagger.svg)](https://crates.io/crates/swagger)

A set of common utilities for crates generated by the `rust-server` [openapi-generator](https://github.com/OpenAPITools/openapi-generator) generator

# Releasing a new version

1. Run `./release-changelog.sh <version>` to update the changelog and `Cargo.toml`
2. Commit and push your changes.
3. Wait for a travis build to complete successfully.
4. Run `cargo publish`.
5. Tag the new version and push the tag.
