#' swagger: Dynamically Generates Documentation from a Swagger-Compliant API
#'
#' Swagger is a collection of HTML, JavaScript, and CSS assets that
#' dynamically generate beautiful documentation from a Swagger-compliant API.
#'
#' The main purpose of this package is to enable package authors to create
#' APIs that are compatible with \url{https://swagger.io/}
#' and \url{https://www.openapis.org/}.
#'
#' To learn more about Swagger visit: \url{https://swagger.io/swagger-ui/}
#'
"_PACKAGE"
